==> haskell-hakyll-4.9.8.0-54-i686.pkg.tar.xz: usr/share/haskell/register/haskell-hakyll.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hakyll
version: 4.9.8.0
id: hakyll-4.9.8.0-LoCey5x9s8lB5EzV8o1uBu
key: hakyll-4.9.8.0-LoCey5x9s8lB5EzV8o1uBu
license: BSD3
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
homepage: http://jaspervdj.be/hakyll
synopsis: A static website compiler library
description:
    Hakyll is a static website compiler library. It provides you with the tools to
    create a simple or advanced static website using a Haskell DSL and formats
    such as markdown or RST. You can find more information, including a tutorial,
    on the website:
    .
    * <http://jaspervdj.be/hakyll>
    .
    If you seek assistance, there'\''s:
    .
    * A google group: <http://groups.google.com/group/hakyll>
    .
    * An IRC channel, @#hakyll@ on freenode
    .
    Additionally, there'\''s the Haddock documentation in the different modules,
    meant as a reference.
category: Web
author: Jasper Van der Jeugt <m@jaspervdj.be>
exposed: True
indefinite: False
exposed-modules:
    Hakyll Hakyll.Commands Hakyll.Core.Compiler
    Hakyll.Core.Compiler.Internal Hakyll.Core.Configuration
    Hakyll.Core.Dependencies Hakyll.Core.File Hakyll.Core.Identifier
    Hakyll.Core.Identifier.Pattern Hakyll.Core.Item Hakyll.Core.Logger
    Hakyll.Core.Metadata Hakyll.Core.Provider
    Hakyll.Core.Provider.Metadata Hakyll.Core.Routes Hakyll.Core.Rules
    Hakyll.Core.Rules.Internal Hakyll.Core.Runtime Hakyll.Core.Store
    Hakyll.Core.UnixFilter Hakyll.Core.Util.File
    Hakyll.Core.Util.String Hakyll.Core.Writable Hakyll.Main
    Hakyll.Web.CompressCss Hakyll.Web.Feed Hakyll.Web.Html
    Hakyll.Web.Html.RelativizeUrls Hakyll.Web.Paginate
    Hakyll.Web.Pandoc Hakyll.Web.Pandoc.Biblio
    Hakyll.Web.Pandoc.FileType Hakyll.Web.Redirect Hakyll.Web.Tags
    Hakyll.Web.Template Hakyll.Web.Template.Context
    Hakyll.Web.Template.Internal Hakyll.Web.Template.Internal.Element
    Hakyll.Web.Template.Internal.Trim Hakyll.Web.Template.List
hidden-modules: Data.List.Extended Data.Yaml.Extended Hakyll.Check
                Hakyll.Core.Compiler.Require Hakyll.Core.Item.SomeItem
                Hakyll.Core.Provider.Internal Hakyll.Core.Provider.MetadataCache
                Hakyll.Core.Util.Parser Hakyll.Web.Pandoc.Binary Paths_hakyll
                Hakyll.Preview.Poll Hakyll.Preview.Server
abi: f728c5c50c5f0b1b3f3fdd4561f683a1
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/hakyll-4.9.8.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/hakyll-4.9.8.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-hakyll
hs-libraries: HShakyll-4.9.8.0-LoCey5x9s8lB5EzV8o1uBu
depends:
    base-4.10.0.0 binary-0.8.5.1
    blaze-html-0.9.0.1-kPi4af1DH04kfw48f7OOh
    blaze-markup-0.8.0.0-FzqDX3sF5iY7olwigbNHfL bytestring-0.10.8.2
    containers-0.5.10.2 cryptohash-0.11.9-CbyZN7BRHMT5dI4lI46n03
    data-default-0.7.1.1-7D2kYbZAPZs3NL2w6K0r5J deepseq-1.4.3.0
    directory-1.3.0.2 filepath-1.4.1.2
    lrucache-1.2.0.0-KsRiNrCtwVxG2ZZ3nsC2EY
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
    network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx
    network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK
    pandoc-1.19.2.1-1BXKDm5LVlD4I3X9K7EJns
    pandoc-citeproc-0.11.1-9cYGDVmadGm2BDqfEle3xC
    parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh process-1.6.1.0
    random-1.1-DtLcP2Z2iOOC0RwcSmXjBK
    regex-base-0.93.2-JCwi1xoDPWa357q45CDi55
    regex-tdfa-1.2.2-1G5AA2OVGrl1AkVWQSHaiw
    resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9
    scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q
    tagsoup-0.14.1-Dd68OXPvIKPH8wN6EGE1ft
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz time-1.8.0.2
    time-locale-compat-0.1.1.3-7E64RB3bIEXLKIO2d5DlHe
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
    yaml-0.8.23.3-Hxrrlqfmicr4pp6WmaArsD
    optparse-applicative-0.14.0.0-CJtbqXiElwvHJ8bj23xDw2
    wai-3.2.1.1-CAwNUvFeJDT75Lly8r7SRS
    warp-3.2.13-3xPm02vnKdc1gViEPlMAOd
    wai-app-static-3.1.6.1-2sjBi4Q7GNkFezD7TNAEXM
    http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW
    fsnotify-0.2.1.1-DlyPuusiJNu6JLzz0E0brN
    system-filepath-0.4.13.4-H5ZT610b48ZDAWGB9PlvnB
    http-conduit-2.2.3.2-K5gXY4GRHaS6rJlnfLyxiv
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             binary-0.8.5.1=b72be3099f9dcf7a652ee107dea27d54
             blaze-html-0.9.0.1-kPi4af1DH04kfw48f7OOh=a026cdf45341163ef88f9856837f267f
             blaze-markup-0.8.0.0-FzqDX3sF5iY7olwigbNHfL=f07231ccbdf42fb50e1dae1144230e4a
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             cryptohash-0.11.9-CbyZN7BRHMT5dI4lI46n03=ad17babc800f12bcb07195453c20bf46
             data-default-0.7.1.1-7D2kYbZAPZs3NL2w6K0r5J=066f8e1a5e7dca2a5fd62aefb939793f
             deepseq-1.4.3.0=ab64de23c9713e035549193002fe9df0
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             lrucache-1.2.0.0-KsRiNrCtwVxG2ZZ3nsC2EY=1c9de727d8c27f77d460846847a89151
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx=dc3f2353580d7555dd3bad96e9f5af9d
             network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK=dcf3b42c1c39d8e42cbbbf74ea3e6c8c
             pandoc-1.19.2.1-1BXKDm5LVlD4I3X9K7EJns=0b3e7a6d1e0b6185923df798bb724f0c
             pandoc-citeproc-0.11.1-9cYGDVmadGm2BDqfEle3xC=31f7c62e28ea0bbd491ae1efc27c194f
             parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh=da03630454c215de5f3965e7b0f0e5da
             process-1.6.1.0=c0ee388768c3dd5e8b2d80490997add7
             random-1.1-DtLcP2Z2iOOC0RwcSmXjBK=e54cb8ee20631772dc74b0ec551441ab
             regex-base-0.93.2-JCwi1xoDPWa357q45CDi55=d786d2f6db13bc388ce83a914bfdaebd
             regex-tdfa-1.2.2-1G5AA2OVGrl1AkVWQSHaiw=a4a19938ad7bbae62d09937bd32287f4
             resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9=2267b8435957f2f8210cd2fc45f80e4c
             scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q=a0445f54fa186d288e1223c9f60f5307
             tagsoup-0.14.1-Dd68OXPvIKPH8wN6EGE1ft=3fbcc782bd8302af2fafeef32df01fde
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
             time-locale-compat-0.1.1.3-7E64RB3bIEXLKIO2d5DlHe=a6d1338097cefdc7bd8b7f2e3d3d2459
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=7d7e1f3460b904c0be93ffa55855f4d0
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=bde86a27d0899b74a82f3bf1fe9b817c
             yaml-0.8.23.3-Hxrrlqfmicr4pp6WmaArsD=2eb35475272bb52d4b23b237d5ff79ed
             optparse-applicative-0.14.0.0-CJtbqXiElwvHJ8bj23xDw2=8c6e4212da58d8bc69ad7a6f814edde6
             wai-3.2.1.1-CAwNUvFeJDT75Lly8r7SRS=b2b1b36770028b18814f7469d1a17fa5
             warp-3.2.13-3xPm02vnKdc1gViEPlMAOd=7396680f964ea0423adb7f3256807666
             wai-app-static-3.1.6.1-2sjBi4Q7GNkFezD7TNAEXM=456d406463d7f8b06d66a9f94462627c
             http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW=dac2e6d9eb3caedd3c76c9c39d0f2e0c
             fsnotify-0.2.1.1-DlyPuusiJNu6JLzz0E0brN=445d06348dcf50e4ef497755f40f35a8
             system-filepath-0.4.13.4-H5ZT610b48ZDAWGB9PlvnB=fe5a792986a644165f83a6cf5aa32906
             http-conduit-2.2.3.2-K5gXY4GRHaS6rJlnfLyxiv=07e528eb1b8474b5c27868f6df44aacd
haddock-interfaces: /usr/share/doc/haskell-hakyll/html/hakyll.haddock
haddock-html: /usr/share/doc/haskell-hakyll/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hakyll-4.9.8.0-56-i686.pkg.tar.xz: usr/share/haskell/register/haskell-hakyll.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hakyll
version: 4.9.8.0
id: hakyll-4.9.8.0-5WDD7fberwv26sZquIaEC6
key: hakyll-4.9.8.0-5WDD7fberwv26sZquIaEC6
license: BSD3
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
homepage: http://jaspervdj.be/hakyll
synopsis: A static website compiler library
description:
    Hakyll is a static website compiler library. It provides you with the tools to
    create a simple or advanced static website using a Haskell DSL and formats
    such as markdown or RST. You can find more information, including a tutorial,
    on the website:
    .
    * <http://jaspervdj.be/hakyll>
    .
    If you seek assistance, there'\''s:
    .
    * A google group: <http://groups.google.com/group/hakyll>
    .
    * An IRC channel, @#hakyll@ on freenode
    .
    Additionally, there'\''s the Haddock documentation in the different modules,
    meant as a reference.
category: Web
author: Jasper Van der Jeugt <m@jaspervdj.be>
exposed: True
indefinite: False
exposed-modules:
    Hakyll Hakyll.Commands Hakyll.Core.Compiler
    Hakyll.Core.Compiler.Internal Hakyll.Core.Configuration
    Hakyll.Core.Dependencies Hakyll.Core.File Hakyll.Core.Identifier
    Hakyll.Core.Identifier.Pattern Hakyll.Core.Item Hakyll.Core.Logger
    Hakyll.Core.Metadata Hakyll.Core.Provider
    Hakyll.Core.Provider.Metadata Hakyll.Core.Routes Hakyll.Core.Rules
    Hakyll.Core.Rules.Internal Hakyll.Core.Runtime Hakyll.Core.Store
    Hakyll.Core.UnixFilter Hakyll.Core.Util.File
    Hakyll.Core.Util.String Hakyll.Core.Writable Hakyll.Main
    Hakyll.Web.CompressCss Hakyll.Web.Feed Hakyll.Web.Html
    Hakyll.Web.Html.RelativizeUrls Hakyll.Web.Paginate
    Hakyll.Web.Pandoc Hakyll.Web.Pandoc.Biblio
    Hakyll.Web.Pandoc.FileType Hakyll.Web.Redirect Hakyll.Web.Tags
    Hakyll.Web.Template Hakyll.Web.Template.Context
    Hakyll.Web.Template.Internal Hakyll.Web.Template.Internal.Element
    Hakyll.Web.Template.Internal.Trim Hakyll.Web.Template.List
hidden-modules: Data.List.Extended Data.Yaml.Extended Hakyll.Check
                Hakyll.Core.Compiler.Require Hakyll.Core.Item.SomeItem
                Hakyll.Core.Provider.Internal Hakyll.Core.Provider.MetadataCache
                Hakyll.Core.Util.Parser Hakyll.Web.Pandoc.Binary Paths_hakyll
                Hakyll.Preview.Poll Hakyll.Preview.Server
abi: deb0402771c4640b2dbc29c2d42e1b2d
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/hakyll-4.9.8.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/hakyll-4.9.8.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-hakyll
hs-libraries: HShakyll-4.9.8.0-5WDD7fberwv26sZquIaEC6
depends:
    base-4.10.0.0 binary-0.8.5.1
    blaze-html-0.9.0.1-kPi4af1DH04kfw48f7OOh
    blaze-markup-0.8.0.0-FzqDX3sF5iY7olwigbNHfL bytestring-0.10.8.2
    containers-0.5.10.2 cryptohash-0.11.9-CbyZN7BRHMT5dI4lI46n03
    data-default-0.7.1.1-7D2kYbZAPZs3NL2w6K0r5J deepseq-1.4.3.0
    directory-1.3.0.2 filepath-1.4.1.2
    lrucache-1.2.0.0-KsRiNrCtwVxG2ZZ3nsC2EY
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
    network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx
    network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK
    pandoc-1.19.2.1-8Y5SnJ2ekjCGtugksio5yx
    pandoc-citeproc-0.11.1.1-8OWy5k4gLXZCUIqcyjBR9g
    parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh process-1.6.1.0
    random-1.1-DtLcP2Z2iOOC0RwcSmXjBK
    regex-base-0.93.2-JCwi1xoDPWa357q45CDi55
    regex-tdfa-1.2.2-1G5AA2OVGrl1AkVWQSHaiw
    resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9
    scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q
    tagsoup-0.14.1-Dd68OXPvIKPH8wN6EGE1ft
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz time-1.8.0.2
    time-locale-compat-0.1.1.3-7E64RB3bIEXLKIO2d5DlHe
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
    yaml-0.8.23.3-5PA6FoFimacABkGYYUI5Gr
    optparse-applicative-0.14.0.0-CJtbqXiElwvHJ8bj23xDw2
    wai-3.2.1.1-CAwNUvFeJDT75Lly8r7SRS
    warp-3.2.13-3xPm02vnKdc1gViEPlMAOd
    wai-app-static-3.1.6.1-COCCRURiknL9dUWXlxHL8n
    http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW
    fsnotify-0.2.1.1-DlyPuusiJNu6JLzz0E0brN
    system-filepath-0.4.13.4-H5ZT610b48ZDAWGB9PlvnB
    http-conduit-2.2.3.2-3H1iTRlmjLCtUsaJETAdB
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             binary-0.8.5.1=b72be3099f9dcf7a652ee107dea27d54
             blaze-html-0.9.0.1-kPi4af1DH04kfw48f7OOh=a026cdf45341163ef88f9856837f267f
             blaze-markup-0.8.0.0-FzqDX3sF5iY7olwigbNHfL=f07231ccbdf42fb50e1dae1144230e4a
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             cryptohash-0.11.9-CbyZN7BRHMT5dI4lI46n03=ad17babc800f12bcb07195453c20bf46
             data-default-0.7.1.1-7D2kYbZAPZs3NL2w6K0r5J=066f8e1a5e7dca2a5fd62aefb939793f
             deepseq-1.4.3.0=ab64de23c9713e035549193002fe9df0
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             lrucache-1.2.0.0-KsRiNrCtwVxG2ZZ3nsC2EY=1c9de727d8c27f77d460846847a89151
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx=dc3f2353580d7555dd3bad96e9f5af9d
             network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK=dcf3b42c1c39d8e42cbbbf74ea3e6c8c
             pandoc-1.19.2.1-8Y5SnJ2ekjCGtugksio5yx=0ab7a06b79f7d1108cd4299df91fa5c8
             pandoc-citeproc-0.11.1.1-8OWy5k4gLXZCUIqcyjBR9g=d08af778b093fad6435c8e23a9d83b03
             parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh=da03630454c215de5f3965e7b0f0e5da
             process-1.6.1.0=c0ee388768c3dd5e8b2d80490997add7
             random-1.1-DtLcP2Z2iOOC0RwcSmXjBK=e54cb8ee20631772dc74b0ec551441ab
             regex-base-0.93.2-JCwi1xoDPWa357q45CDi55=d786d2f6db13bc388ce83a914bfdaebd
             regex-tdfa-1.2.2-1G5AA2OVGrl1AkVWQSHaiw=a4a19938ad7bbae62d09937bd32287f4
             resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9=2267b8435957f2f8210cd2fc45f80e4c
             scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q=a0445f54fa186d288e1223c9f60f5307
             tagsoup-0.14.1-Dd68OXPvIKPH8wN6EGE1ft=3fbcc782bd8302af2fafeef32df01fde
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
             time-locale-compat-0.1.1.3-7E64RB3bIEXLKIO2d5DlHe=a6d1338097cefdc7bd8b7f2e3d3d2459
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=7d7e1f3460b904c0be93ffa55855f4d0
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=bde86a27d0899b74a82f3bf1fe9b817c
             yaml-0.8.23.3-5PA6FoFimacABkGYYUI5Gr=3efef415fb37938945c14dfc2fd6675d
             optparse-applicative-0.14.0.0-CJtbqXiElwvHJ8bj23xDw2=8c6e4212da58d8bc69ad7a6f814edde6
             wai-3.2.1.1-CAwNUvFeJDT75Lly8r7SRS=b2b1b36770028b18814f7469d1a17fa5
             warp-3.2.13-3xPm02vnKdc1gViEPlMAOd=7396680f964ea0423adb7f3256807666
             wai-app-static-3.1.6.1-COCCRURiknL9dUWXlxHL8n=a117bb39d1db94e95d963492996f8ec3
             http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW=dac2e6d9eb3caedd3c76c9c39d0f2e0c
             fsnotify-0.2.1.1-DlyPuusiJNu6JLzz0E0brN=445d06348dcf50e4ef497755f40f35a8
             system-filepath-0.4.13.4-H5ZT610b48ZDAWGB9PlvnB=fe5a792986a644165f83a6cf5aa32906
             http-conduit-2.2.3.2-3H1iTRlmjLCtUsaJETAdB=6ddf39923b90b9196bbfe0c8b98a9104
haddock-interfaces: /usr/share/doc/haskell-hakyll/html/hakyll.haddock
haddock-html: /usr/share/doc/haskell-hakyll/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
